# netband
inter[net] [band]width

Command line interface for testing internet bandwidth using speedtest.net. A maintained fork of [speedtest-cli](https://github.com/sivel/speedtest-cli). All the feature of 'speedtest-cli' is available in 'netband' without the depreciation warnings.

# Installation
`pip install netband`

# Future
+ Unnecessary features will get removed.
+ Fixing bugs.
+ Restructuring the source code.
+ Maintaining the project.
